@@ -1,7 +1,7 @@
 package App::UniqFiles;
 
-our $DATE = '2017-07-10'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $DATE = '2019-12-04'; # DATE
+our $VERSION = '0.130'; # VERSION
 
 use 5.010001;
 use strict;
@@ -220,7 +220,7 @@ App::UniqFiles - Report or omit duplicate file contents
 
 =head1 VERSION
 
-This document describes version 0.12 of App::UniqFiles (from Perl distribution App-UniqFiles), released on 2017-07-10.
+This document describes version 0.130 of App::UniqFiles (from Perl distribution App-UniqFiles), released on 2019-12-04.
 
 =head1 SYNOPSIS
 
@@ -238,7 +238,7 @@ device), so don't feed them.
 
 Usage:
 
- uniq_files(%args) -> [status, msg, result, meta]
+ uniq_files(%args) -> [status, msg, payload, meta]
 
 Report or omit duplicate file contents.
 
@@ -295,7 +295,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -317,13 +317,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<find-duplicate-filenames> from L<App::FindUtils>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2015, 2014, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2017, 2015, 2014, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
